@@ -1,6 +1,6 @@
 /* b-anchor.c --- constant data and their lookup funcs
 
-   Copyright (C) 2010-2014 Thien-Thi Nguyen
+   Copyright (C) 2010-2015 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -103,7 +103,7 @@ pool_lookup (const uint8_t pool[], struct cbuf const *x,
     {
       size_t symlen = *p;
 
-      if (x->size == symlen && !memcmp (p + 1, x->string, symlen))
+      if (x->size == symlen && MEM_SAME (symlen, p + 1, x->string))
         {
           found->i = i;
           found->sym = (struct tinysym const *) p;
