@@ -1,6 +1,6 @@
 /* Check in revisions of RCS files from working files.
 
-   Copyright (C) 2010-2013 Thien-Thi Nguyen
+   Copyright (C) 2010-2015 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -66,7 +66,7 @@ static void
 cleanup (int *exitstatus, struct work *work)
 {
   if (FLOW (erroneousp))
-    *exitstatus = EXIT_FAILURE;
+    *exitstatus = exit_failure;
   fro_zclose (&FLOW (from));
   fro_zclose (&work->fro);
   Ozclose (&work->ex);
@@ -266,6 +266,13 @@ prune (struct delta *wrong, struct delta *bp)
   if (0 >= same)
     return;
 
+  /* If ‘wrong’ is the ‘bp’ successor, simply forget it.  */
+  if (wrong == bp->ilk)
+    {
+       bp->ilk = NULL;
+       return;
+    }
+
   /* If ‘wrong’ is the only revision on a branch, delete that branch.  */
   box.next = bp->branches;
   for (tp = &box; tp->next; tp = tp->next)
@@ -1069,23 +1076,27 @@ ci_main (const char *cmd, int argc, char **argv)
                 SAME_AFTER (from, bud.target->text);
                 bud.d.pretty_log = getlogmsg (&reason, &bud);
 
-                /* "Rewind" ‘work.fro’ before feeding it to diff(1).  */
-                fro_bob (work.fro);
+		/* Make sure diff(1) reads from the beginning.  */
                 if (PROB (lseek (wfd, 0, SEEK_SET)))
                   Ierror ();
 
                 diffp = diffv;
                 *++diffp = prog_diff;
                 *++diffp = diff_flags;
-#if OPEN_O_BINARY
-                if (kws == kwsub_b)
+                if (OPEN_O_BINARY
+                    && kws == kwsub_b)
                   *++diffp = "--binary";
-#endif
                 *++diffp = newhead ? "-" : expname;
                 *++diffp = newhead ? expname : "-";
                 *++diffp = NULL;
                 if (DIFF_TROUBLE == runv (wfd, diffname, diffv))
                   RFATAL ("diff failed");
+
+                /* "Rewind" ‘work.fro’ only after feeding it to
+		   diff(1).  This is needed to keep the stream
+		   buffer state in sync with the fd. */
+                fro_bob (work.fro);
+
                 if (newhead)
                   {
                     fro_bob (work.fro);
