@@ -1,6 +1,6 @@
 /* Parse a string, returning a ‘struct partime’ that describes it.
 
-   Copyright (C) 2010-2013 Thien-Thi Nguyen
+   Copyright (C) 2010-2015 Thien-Thi Nguyen
    Copyright (C) 1993, 1994, 1995 Paul Eggert
 
    This file is part of GNU RCS.
@@ -34,13 +34,13 @@ struct name_val
   int val;
 };
 
-static const struct name_val const month_names[] = {
+static const struct name_val month_names[] = {
   {"jan", 0}, {"feb", 1}, {"mar", 2}, {"apr", 3}, {"may", 4}, {"jun", 5},
   {"jul", 6}, {"aug", 7}, {"sep", 8}, {"oct", 9}, {"nov", 10}, {"dec", 11},
   {"", TM_UNDEFINED}
 };
 
-static const struct name_val const weekday_names[] = {
+static const struct name_val weekday_names[] = {
   {"sun", 0}, {"mon", 1}, {"tue", 2}, {"wed", 3}, {"thu", 4}, {"fri", 5},
   {"sat", 6}, {"", TM_UNDEFINED}
 };
@@ -50,7 +50,7 @@ static const struct name_val const weekday_names[] = {
 #define zs(t,s)  {s, hr60(t)}
 #define zd(t,s,d)  zs(t, s),  zs((t)+100, d)
 
-static const struct name_val const zone_names[] = {
+static const struct name_val zone_names[] = {
   zs (-1000, "hst"),            /* Hawaii */
   zd (-1000, "hast", "hadt"),   /* Hawaii-Aleutian */
   zd (-900, "akst", "akdt"),    /* Alaska */
@@ -150,7 +150,7 @@ lookup (char const *s, struct name_val const table[])
    returning val for first matching entry.  */
 {
   int j;
-  char buf[NAME_LENGTH_MAXIMUM];
+  char buf[NAME_LENGTH_MAXIMUM] = { 0 };
 
   for (j = 0; j < NAME_LENGTH_MAXIMUM; j++)
     {
